EEA coastline regions of Europe (EPSG:25832)
co.RdCoastline regions from the European Environment Agency in Projection EPSG:25832.
Usage
data(coastline_regions_epsg25832)
co.RdCoastline regions from the European Environment Agency in Projection EPSG:25832.
data(coastline_regions_epsg25832)