List available classifications
resy_available_classifications.RdLists the classification schemes and versions bundled with the package (under `inst/extdata/classifications/`).

resy_available_classifications.RdLists the classification schemes and versions bundled with the package (under `inst/extdata/classifications/`).